@@ -4,8 +4,8 @@
 
 test_dir=$(dirname $0)
 
-export WORKON_HOME="${TMPDIR:-/tmp}/WORKON_HOME"
-export PROJECT_HOME="${TMPDIR:-/tmp}/PROJECT_HOME"
+export WORKON_HOME="$(echo ${TMPDIR:-/tmp}/WORKON_HOME | sed 's|//|/|g')"
+export PROJECT_HOME="$(echo ${TMPDIR:-/tmp}/PROJECT_HOME | sed 's|//|/|g')"
 
 oneTimeSetUp() {
     rm -rf "$WORKON_HOME"
@@ -13,7 +13,6 @@ oneTimeSetUp() {
     rm -rf "$PROJECT_HOME"
     mkdir -p "$PROJECT_HOME"
     source "$test_dir/util.sh"
-    load_virtualenvwrapper
 }
 
 oneTimeTearDown() {
@@ -27,6 +26,7 @@ setUp () {
 }
 
 test_initialize() {
+    load_virtualenvwrapper
     for hook in  premkproject postmkproject prermproject postrmproject
     do
         assertTrue "Global $hook was not created" "[ -f $WORKON_HOME/$hook ]"
@@ -34,6 +34,18 @@ test_initialize() {
     done
 }
 
+test_initialize_hook_dir() {
+    export VIRTUALENVWRAPPER_HOOK_DIR="$WORKON_HOME/hooks"
+    mkdir -p "$VIRTUALENVWRAPPER_HOOK_DIR"
+    load_virtualenvwrapper
+    for hook in  premkproject postmkproject prermproject postrmproject
+    do
+        assertTrue "Global $hook was not created" "[ -f $VIRTUALENVWRAPPER_HOOK_DIR/$hook ]"
+        assertTrue "Global $hook is not executable" "[ -x $VIRTUALENVWRAPPER_HOOK_DIR/$hook ]"
+    done
+    VIRTUALENVWRAPPER_HOOK_DIR="$WORKON_HOME"
+}
+
 test_virtualenvwrapper_verify_project_home() {
     assertTrue "PROJECT_HOME not verified" virtualenvwrapper_verify_project_home
 }
