@@ -4,8 +4,8 @@
 
 test_dir=$(dirname $0)
 
-export WORKON_HOME="${TMPDIR:-/tmp}WORKON_HOME"
-export PROJECT_HOME="${TMPDIR:-/tmp}PROJECT_HOME"
+export WORKON_HOME="$(echo ${TMPDIR:-/tmp}/WORKON_HOME | sed 's|//|/|g')"
+export PROJECT_HOME="$(echo ${TMPDIR:-/tmp}/PROJECT_HOME | sed 's|//|/|g')"
 
 oneTimeSetUp() {
     rm -rf "$WORKON_HOME"
@@ -27,7 +27,7 @@ setUp () {
 }
 
 test_activate () {
-    mkproject myproject
+    mkproject myproject >/dev/null 2>&1
     deactivate
     cd $TMPDIR
     workon myproject
@@ -40,7 +40,7 @@ test_space_in_path () {
     old_project_home="$PROJECT_HOME"
     PROJECT_HOME="$PROJECT_HOME/with spaces"
     mkdir -p "$PROJECT_HOME"
-    mkproject "myproject"
+    mkproject "myproject" >/dev/null 2>&1
     deactivate
     cd $TMPDIR
     workon "myproject"
