@@ -4,8 +4,8 @@
 
 test_dir=$(dirname $0)
 
-export WORKON_HOME="${TMPDIR:-/tmp}WORKON_HOME"
-export PROJECT_HOME="${TMPDIR:-/tmp}PROJECT_HOME"
+export WORKON_HOME="$(echo ${TMPDIR:-/tmp}/WORKON_HOME | sed 's|//|/|g')"
+export PROJECT_HOME="$(echo ${TMPDIR:-/tmp}/PROJECT_HOME | sed 's|//|/|g')"
 
 oneTimeSetUp() {
     rm -rf "$WORKON_HOME"
@@ -27,7 +27,7 @@ setUp () {
 }
 
 test_with_project () {
-    mkproject myproject
+    mkproject myproject >/dev/null 2>&1
     cd $TMPDIR
     cdproject
     assertSame "$PROJECT_HOME/myproject" "$(pwd)"
@@ -35,7 +35,7 @@ test_with_project () {
 }
 
 test_without_project () {
-    mkvirtualenv myproject
+    mkvirtualenv myproject >/dev/null 2>&1
     cd $TMPDIR
     output=$(cdproject 2>&1)
     echo "$output" | grep -q "No project set"
@@ -48,7 +48,7 @@ test_space_in_path () {
     old_project_home="$PROJECT_HOME"
     PROJECT_HOME="$PROJECT_HOME/with spaces"
     mkdir -p "$PROJECT_HOME"
-    mkproject "myproject"
+    mkproject "myproject" >/dev/null 2>&1
     cd $TMPDIR
     cdproject
     assertSame "$PROJECT_HOME/myproject" "$(pwd)"
