@@ -4,8 +4,8 @@
 
 test_dir=$(dirname $0)
 
-export WORKON_HOME="${TMPDIR:-/tmp}WORKON_HOME"
-export PROJECT_HOME="${TMPDIR:-/tmp}PROJECT_HOME"
+export WORKON_HOME="$(echo ${TMPDIR:-/tmp}/WORKON_HOME | sed 's|//|/|g')"
+export PROJECT_HOME="$(echo ${TMPDIR:-/tmp}/PROJECT_HOME | sed 's|//|/|g')"
 
 oneTimeSetUp() {
     rm -rf "$WORKON_HOME"
@@ -27,7 +27,7 @@ setUp () {
 }
 
 test_list_templates () {
-    mkproject myproject
+    mkproject myproject >/dev/null 2>&1
     output=`mkproject myproject 2>&1`
     assertTrue "Did not see expected message" "echo $output | grep 'already exists'"
     deactivate
